The PyWBEM Client Attic
=======================

This directory exists in order to hold files that are not really used or
supported at this point. These may be old things that never made it into
bright daylight, or new things that were started at some point but were never
finished.

These files are generally ignored in any descriptions about the PyWBEM Client.

This directory contains the following files:

* `cim_provider.py`, `cim_provider2.py`:
  An attempt to write CIM providers in Python. Status is not clear.

* `twisted_client.py`:
  An attempt to use the python Twisted package for a rewrite of the PyWBEM
  Client. Status is not clear.

* `cimxml_parse.py`, `test_cimxml_parse.py`:
  An attempt to rewrite the CIM-XML parser of the PyWBEM Client in a better
  way. It runs through its unit test cases and has been ported to Python 3,
  but it was never used.

